# Niching Migratory Multi-Swarm Optimser for Python (pynmmso)

Python implementation of the Niching Migratory Multi-Swarm Optimser, described
in: "*Running Up Those Hills: Multi-Modal Search with the Niching Migratory Multi-Swarm Optimiser*"
by Jonathan E. Fieldsend published in Proceedings of the IEEE Congress on Evolutionary Computation, 
pages 2593-2600, 2014 (http://hdl.handle.net/10871/15247)

Please reference this paper if you undertake work utilising this code.

Documentation for pynmmso can be found at: https://github.com/EPCCed/pynmmso/wiki/NMMSO



